package de.thdeg.greiner.superpangworld.graphics.moveable;

import de.thdeg.greiner.superpangworld.gameview.GameView;
import de.thdeg.greiner.superpangworld.graphics.base.Bubble;
import de.thdeg.greiner.superpangworld.graphics.base.CollidableGameObject;

import java.awt.*;
import java.util.ArrayList;
import java.util.Random;


/**
 * The classic red, round bubble.
 */
public class RoundBubble extends Bubble {

    /** The pixel art for the bubble */
    private final static String RED_BUBBLE =
            "    RRRR    \n"+
                    "   RWRRRR   \n"+
                    "  RWRRRRRR  \n"+
                    " RWRRRRRRRR \n"+
                    "RWRRRRRRRRRR\n"+
                    "RWRRRRRRRRRR\n"+
                    "RWRRRRRRRRWR\n"+
                    "RRRRRRRRRWWR\n"+
                    " RRRRRRRWWR \n"+
                    "  RRRRRWWR  \n"+
                    "   RRRWWR   \n"+
                    "    RRRR    \n";

    /**
     * Create a round bubble with default values.
     *
     * @param gameView the {@link GameView} to display the bubble
     * @param objectsToCollideWith the list of {@link CollidableGameObject} the bubble can collide with
     */
    public RoundBubble(GameView gameView, ArrayList<CollidableGameObject> objectsToCollideWith) {
        super(gameView,objectsToCollideWith);

        Random rand = new Random();
        position.setTo(rand.nextInt(GameView.WIDTH),rand.nextInt(GameView.HEIGHT));

        this.hitBox.width = width-20;
        this.hitBox.height = height-20;
    }

    @Override
    protected void updateHitBoxPosition() {
        hitBox.x = (int) (position.x+10);
        hitBox.y = (int) (position.y+10);
    }

    /**
     * Draws the bubble onto the canvas of the {@link GameView}.
     */
    @Override
    public void addToCanvas(){
        gameView.addBlockImageToCanvas(RED_BUBBLE, getPosition().x, getPosition().y,size, rotation);
        gameView.addRectangleToCanvas(hitBox.x, hitBox.y, hitBox.width, hitBox.height,1,false, Color.yellow);
    }

    @Override
    public void updateStatus() {

    }
}
